<div align="center">
  <h1>From zero to GPT-hero with Keras 3</h1>
</div>

## 📖 Reading list

Find the GPT-reading list at [hf.co/collections/alvarobartt/from-zero-to-gpt-hero](https://huggingface.co/collections/alvarobartt/from-zero-to-gpt-hero-650b112cee5dfd0c2a5e0ecb).
